function q = qbb(v,t)
% QBB Inverse of the CDF of the maximum of the Brownian Bridge process
% defined on [0,T].
%
% 
% Syntax
%          q = qbb(p,t)
%          q = qbb(p)
%
% Description
% QBB(P,T) computes the critical value of the cumulative distribution 
% function of the maximum of the Brownian Bridge defined on [0,T] at each 
% of the probability values in P.
% The parameter T be a positive scalar.
% The default value of parameter T is 1.
%

% Version 2010/11/03
% Li-Vang Lozada-Chang
%
u = sqrt(-1/2*log(1-v));
q = sqrt(t)*u;

end 