function Q = qou(P, t)
% QOU inverse of CDF of the supremum of the Ornstein-Uhlenbeck process
%
% Syntax
%   q = qou(p,t)
%   q = qou(p)
%
% Description
% QOU(P,T) computes the inverse of the cumulative distribution function of
% the supremum of the absolute value of the Normalized Bessel Process in 
% the interval [0,T] at each of the values in P.
% The input parameter T must be a positive scalar. The values in P must
% probability values.
% The default value of parameter T is 1.
%
% Remark
% The computation is possible for 0 < q < 5. 
% P must be equal or greater than 0.25. 
%
% Reference
% 1- "Crossing probabilities for a square root boundary by a Bessel
%     process" by DeLong, David M
%     Commun. Stat., Theory Methods A, 1981.
% 2- "A toolbox note on the distribution of the maximum of Gaussian process"
%    by Azais, J.M. & Lozada-Chang, L.
%
% Version 2012/10/11
% Li-Vang Lozada-Chang

if nargin < 2,
    t = 1;
end

T = exp(2*t);   %modfie 2018
Q = qbp(P, T);

end